@@ -63,7 +63,7 @@ class DefinitionRegistry(KoiledModel):
         structure_registry: StructureRegistry,
         actifier: Actifier = None,
         interface: str = None,
-        widgets: Dict[str, WidgetInput] = {},
+        widgets: Dict[str, WidgetInput] = None,
         interfaces: List[str] = [],
         on_provide=None,
         on_unprovide=None,
